Module schema

Module schema 

Structs

CalendarRecord
Structure representing details of a calendar record
ChartLastInfoRecord
Specification and constraints for the requested data
ChartRangeInfoRecord
Structure representing chart range information
ErrorResponse
Response message returned from server when operation fails.
GetAllSymbolsRequest
Only logic struct to keep symmetry. The getAllSymbols command has no request data.
GetAllSymbolsResponse
Wrapper for symbols
GetCalendarRequest
The request has no data. This struct exists only to keep symmetry
GetCalendarResponse
GetChartLastRequestRequest
Get chart information Please note that this function can be usually replaced by its streaming equivalent getCandles which is the preferred way of retrieving current candle data.
GetChartLastRequestResponse
Structure representing details of rate information
GetChartRangeRequestRequest
Structure representing chart range details
GetCommissionDefRequest
Request for calculation of commission
GetCommissionDefResponse
GetCurrentUserDataRequest
GetCurrentUserDataResponse
Structure representing account details
GetIbsHistoryRequest
Structure representing IB’s history block
GetIbsHistoryResponse
GetMarginLevelRequest
GetMarginLevelResponse
Structure representing account financial information
GetMarginTradeRequest
GetMarginTradeResponse
Structure representing margin information
GetNewsRequest
Structure representing a specific Time span
GetNewsResponse
GetProfitCalculationRequest
Structure representing the order with operation code, price and volume
GetProfitCalculationResponse
Structure representing profit information
GetServerTimeRequest
GetServerTimeResponse
Structure representing time information
GetStepRulesRequest
GetStepRulesResponse
GetSymbolRequest
Structure representing a symbol
GetTickPricesRequest
Structure representing a level
GetTickPricesResponse
GetTradeRecordsRequest
GetTradeRecordsResponse
GetTradesHistoryRequest
Structure representing a time interval
GetTradesRequest
GetTradingHoursRequest
GetTradingHoursResponse
GetVersionRequest
GetVersionResponse
HoursRecord
IBRecord
Structure representing IB data
LoginRequest
Structure representing user’s login data
LoginResponse
Only logic struct to keep symmetry. The login command has no response.
NewsBodyRecord
Structure representing a news item
PingRequest
PingResponse
RateInfoRecord
Structure representing details of a rate
Request
Message sent to XTB servers
Response
Response message returned from server when operation succeeds.
StepRecord
Structure representing a record step
StepRuleRecord
Structure representing a step rule
StreamDataMessage
Data stream item representation
StreamGetBalanceData
StreamGetBalanceSubscribe
StreamGetBalanceUnsubscribe
StreamGetCandlesData
StreamGetCandlesSubscribe
StreamGetCandlesUnsubscribe
StreamGetKeepAliveData
StreamGetKeepAliveSubscribe
StreamGetKeepAliveUnsubscribe
StreamGetNewsData
StreamGetNewsSubscribe
StreamGetNewsUnsubscribe
StreamGetProfitData
StreamGetProfitSubscribe
StreamGetProfitUnsubscribe
StreamGetTickPricesData
StreamGetTickPricesSubscribe
StreamGetTickPricesUnsubscribe
StreamGetTradeStatusData
StreamGetTradeStatusSubscribe
StreamGetTradeStatusUnsubscribe
StreamGetTradesData
StreamGetTradesSubscribe
StreamGetTradesUnsubscribe
StreamPingSubscribe
SubscribeRequest
Subscribe for stream of data
SymbolRecord
Structure representing details of a financial symbol
TickRecord
Structure representing market price data
TradeRecord
Structure representing a trade order
TradeTransInfo
TradeTransactionRequest
Structure embedding a TRADE_TRANS_INFO instance
TradeTransactionResponse
TradeTransactionStatusRequest
TradeTransactionStatusResponse
Structure representing the response
TradingHoursRecord
UnsubscribeRequest
Unsubscribe from stream of data

Enums

DayOfWeek
ImpactLevel
Expected impact level of event in calendar
MarginMode
Enum representing different margin modes
ProfitMode
Enum representing different profit modes
QuoteId
Enum representing various types
TimePeriod
Enum representing different time periods
TradeStatus
TradingAction
Enum representing types of trading actions
TradingCommand
Enum representing different types of trading actions
TransactionStatus
TransactionType
XtbErrorCode
Rust enum definition for error codes
XtbErrorCodeError

Constants

COMMAND_GET_ALL_SYMBOLS
COMMAND_GET_CALENDAR
COMMAND_GET_CHART_LAST_REQUEST
COMMAND_GET_CHART_RANGE_REQUEST
COMMAND_GET_COMMISSION_DEF
COMMAND_GET_CURRENT_USER_DATA
COMMAND_GET_IBS_HISTORY
COMMAND_GET_MARGIN_LEVEL
COMMAND_GET_MARGIN_TRADE
COMMAND_GET_NEWS
COMMAND_GET_PROFIT_CALCULATION
COMMAND_GET_SERVER_TIME
COMMAND_GET_STEP_RULES
COMMAND_GET_SYMBOL
COMMAND_GET_TICK_PRICES
COMMAND_GET_TRADES
COMMAND_GET_TRADES_HISTORY
COMMAND_GET_TRADE_RECORDS
COMMAND_GET_TRADING_HOURS
COMMAND_GET_VERSION
COMMAND_LOGIN
COMMAND_LOGOUT
COMMAND_PING
COMMAND_TRADE_TRANSACTION
COMMAND_TRADE_TRANSACTION_STATUS
STREAM_BALANCE
STREAM_BALANCE_SUBSCRIBE
STREAM_BALANCE_UNSUBSCRIBE
STREAM_CANDLES
STREAM_CANDLES_SUBSCRIBE
STREAM_CANDLES_UNSUBSCRIBE
STREAM_KEEP_ALIVE
STREAM_KEEP_ALIVE_SUBSCRIBE
STREAM_KEEP_ALIVE_UNSUBSCRIBE
STREAM_NEWS
STREAM_NEWS_SUBSCRIBE
STREAM_NEWS_UNSUBSCRIBE
STREAM_PING
STREAM_PROFITS
STREAM_PROFITS_SUBSCRIBE
STREAM_PROFITS_UNSUBSCRIBE
STREAM_TICK_PRICES
STREAM_TICK_PRICES_SUBSCRIBE
STREAM_TICK_PRICES_UNSUBSCRIBE
STREAM_TRADES
STREAM_TRADES_SUBSCRIBE
STREAM_TRADES_UNSUBSCRIBE
STREAM_TRADE_STATUS
STREAM_TRADE_STATUS_SUBSCRIBE
STREAM_TRADE_STATUS_UNSUBSCRIBE

Type Aliases

GetChartRangeRequestResponse
Response for the getChartRangeRequest is same as getChartLastRequest
GetSymbolResponse
GetTradesHistoryResponse
List of trade records
GetTradesResponse
List of trade records