pub struct GetCurrentUserDataResponse {
pub company_unit: i64,
pub currency: String,
pub group: String,
pub ib_account: bool,
pub leverage: i64,
pub leverage_multiplier: Decimal,
pub spread_type: Option<String>,
pub trailing_stop: bool,
}Expand description
Structure representing account details
Fields
company_unit: i64Unit the account is assigned to
currency: StringAccount currency
group: StringGroup
ib_account: boolIndicates whether this account is an IB account
leverage: i64This field should not be used. It is inactive and its value is always 1
leverage_multiplier: DecimalThe factor used for margin calculations. The actual value of leverage can be calculated by dividing this value by 100
spread_type: Option<String>SpreadType, null if not applicable
trailing_stop: boolIndicates whether this account is enabled to use trailing stop
Implementations
Sourceimpl GetCurrentUserDataResponse
impl GetCurrentUserDataResponse
Sourcepub fn with_company_unit(self, value: impl Into<i64>) -> Self
pub fn with_company_unit(self, value: impl Into<i64>) -> Self
Sets the company_unit field of this struct.
Sourcepub fn with_currency(self, value: impl Into<String>) -> Self
pub fn with_currency(self, value: impl Into<String>) -> Self
Sets the currency field of this struct.
Sourcepub fn with_group(self, value: impl Into<String>) -> Self
pub fn with_group(self, value: impl Into<String>) -> Self
Sets the group field of this struct.
Sourcepub fn with_ib_account(self, value: impl Into<bool>) -> Self
pub fn with_ib_account(self, value: impl Into<bool>) -> Self
Sets the ib_account field of this struct.
Sourcepub fn with_leverage(self, value: impl Into<i64>) -> Self
pub fn with_leverage(self, value: impl Into<i64>) -> Self
Sets the leverage field of this struct.
Sourcepub fn with_leverage_multiplier(self, value: impl Into<Decimal>) -> Self
pub fn with_leverage_multiplier(self, value: impl Into<Decimal>) -> Self
Sets the leverage_multiplier field of this struct.
Sourcepub fn with_spread_type(self, value: impl Into<String>) -> Self
pub fn with_spread_type(self, value: impl Into<String>) -> Self
Sets the spread_type field of this struct.
Sourcepub fn with_trailing_stop(self, value: impl Into<bool>) -> Self
pub fn with_trailing_stop(self, value: impl Into<bool>) -> Self
Sets the trailing_stop field of this struct.