pub struct IBRecord {
pub close_price: Option<Decimal>,
pub login: Option<String>,
pub nominal: Option<Decimal>,
pub open_price: Option<Decimal>,
pub side: Option<TradingAction>,
pub surname: Option<String>,
pub symbol: Option<String>,
pub timestamp: Option<u64>,
pub volume: Option<Decimal>,
}Expand description
Structure representing IB data
Fields
close_price: Option<Decimal>IB close price or null if not allowed to view
login: Option<String>IB user login or null if not allowed to view
nominal: Option<Decimal>IB nominal or null if not allowed to view
open_price: Option<Decimal>IB open price or null if not allowed to view
side: Option<TradingAction>Operation code or null if not allowed to view
surname: Option<String>IB user surname or null if not allowed to view
symbol: Option<String>Symbol or null if not allowed to view
timestamp: Option<u64>Time the record was created or null if not allowed to view
volume: Option<Decimal>Volume in lots or null if not allowed to view
Implementations
Sourceimpl IBRecord
impl IBRecord
Sourcepub fn with_close_price(self, value: impl Into<Decimal>) -> Self
pub fn with_close_price(self, value: impl Into<Decimal>) -> Self
Sets the close_price field of this struct.
Sourcepub fn with_login(self, value: impl Into<String>) -> Self
pub fn with_login(self, value: impl Into<String>) -> Self
Sets the login field of this struct.
Sourcepub fn with_nominal(self, value: impl Into<Decimal>) -> Self
pub fn with_nominal(self, value: impl Into<Decimal>) -> Self
Sets the nominal field of this struct.
Sourcepub fn with_open_price(self, value: impl Into<Decimal>) -> Self
pub fn with_open_price(self, value: impl Into<Decimal>) -> Self
Sets the open_price field of this struct.
Sourcepub fn with_side(self, value: impl Into<TradingAction>) -> Self
pub fn with_side(self, value: impl Into<TradingAction>) -> Self
Sets the side field of this struct.
Sourcepub fn with_surname(self, value: impl Into<String>) -> Self
pub fn with_surname(self, value: impl Into<String>) -> Self
Sets the surname field of this struct.
Sourcepub fn with_symbol(self, value: impl Into<String>) -> Self
pub fn with_symbol(self, value: impl Into<String>) -> Self
Sets the symbol field of this struct.
Sourcepub fn with_timestamp(self, value: impl Into<u64>) -> Self
pub fn with_timestamp(self, value: impl Into<u64>) -> Self
Sets the timestamp field of this struct.
Sourcepub fn with_volume(self, value: impl Into<Decimal>) -> Self
pub fn with_volume(self, value: impl Into<Decimal>) -> Self
Sets the volume field of this struct.