NewsBodyRecord

Struct NewsBodyRecord 

pub struct NewsBodyRecord {
    pub body: String,
    pub body_len: usize,
    pub key: String,
    pub time: u64,
    pub time_string: String,
    pub title: String,
}
Structure representing a news item

Fields

body: String

News body content

body_len: usize

Length of the news body content

key: String

The key of the news item

time: u64

Time when the news was posted, represented as a UNIX timestamp

time_string: String

Time when the news was posted, presented in string format

title: String

Title of the news item

Implementations

Source

impl NewsBodyRecord

pub fn with_body(self, value: impl Into<String>) -> Self

Sets the body field of this struct.

pub fn with_body_len(self, value: impl Into<usize>) -> Self

Sets the body_len field of this struct.

pub fn with_key(self, value: impl Into<String>) -> Self

Sets the key field of this struct.

pub fn with_time(self, value: impl Into<u64>) -> Self

Sets the time field of this struct.

pub fn with_time_string(self, value: impl Into<String>) -> Self

Sets the time_string field of this struct.

pub fn with_title(self, value: impl Into<String>) -> Self

Sets the title field of this struct.