pub struct StreamGetCandlesData {
pub close: Decimal,
pub ctm: u64,
pub ctm_string: String,
pub high: Decimal,
pub low: Decimal,
pub open: Decimal,
pub quote_id: QuoteId,
pub symbol: String,
pub vol: Decimal,
}Fields
close: DecimalClose price in base currency
ctm: u64Candle start time in CET time zone (Central European Time)
ctm_string: StringString representation of the ctm field
high: DecimalHighest value in the given period in base currency
low: DecimalLowest value in the given period in base currency
open: DecimalOpen price in base currency
quote_id: QuoteIdSource of price
symbol: StringSymbol
vol: DecimalVolume in lots
Implementations
Sourceimpl StreamGetCandlesData
impl StreamGetCandlesData
Sourcepub fn with_close(self, value: impl Into<Decimal>) -> Self
pub fn with_close(self, value: impl Into<Decimal>) -> Self
Sets the close field of this struct.
Sourcepub fn with_ctm_string(self, value: impl Into<String>) -> Self
pub fn with_ctm_string(self, value: impl Into<String>) -> Self
Sets the ctm_string field of this struct.
Sourcepub fn with_quote_id(self, value: impl Into<QuoteId>) -> Self
pub fn with_quote_id(self, value: impl Into<QuoteId>) -> Self
Sets the quote_id field of this struct.
Sourcepub fn with_symbol(self, value: impl Into<String>) -> Self
pub fn with_symbol(self, value: impl Into<String>) -> Self
Sets the symbol field of this struct.