pub struct StreamGetTickPricesData {
pub ask: Decimal,
pub ask_volume: Option<i32>,
pub bid: Decimal,
pub bid_volume: Option<i32>,
pub high: Decimal,
pub level: i32,
pub low: Decimal,
pub quote_id: QuoteId,
pub spread_raw: Decimal,
pub spread_table: Decimal,
pub symbol: String,
pub timestamp: u64,
}Fields
ask: DecimalAsk price in base currency
ask_volume: Option<i32>Number of available lots to buy at given price
bid: DecimalBid price in base currency
bid_volume: Option<i32>Number of available lots to sell at given price
high: DecimalThe highest price of the day in base currency
level: i32Price level
low: DecimalThe lowest price of the day in base currency
quote_id: QuoteIdSource of price
spread_raw: DecimalThe difference between raw ask and bid prices
spread_table: DecimalSpread representation
symbol: StringFinancial instrument symbol
timestamp: u64Time when the information was updated
Implementations
Sourceimpl StreamGetTickPricesData
impl StreamGetTickPricesData
Sourcepub fn with_ask_volume(self, value: impl Into<i32>) -> Self
pub fn with_ask_volume(self, value: impl Into<i32>) -> Self
Sets the ask_volume field of this struct.
Sourcepub fn with_bid_volume(self, value: impl Into<i32>) -> Self
pub fn with_bid_volume(self, value: impl Into<i32>) -> Self
Sets the bid_volume field of this struct.
Sourcepub fn with_level(self, value: impl Into<i32>) -> Self
pub fn with_level(self, value: impl Into<i32>) -> Self
Sets the level field of this struct.
Sourcepub fn with_quote_id(self, value: impl Into<QuoteId>) -> Self
pub fn with_quote_id(self, value: impl Into<QuoteId>) -> Self
Sets the quote_id field of this struct.
Sourcepub fn with_spread_raw(self, value: impl Into<Decimal>) -> Self
pub fn with_spread_raw(self, value: impl Into<Decimal>) -> Self
Sets the spread_raw field of this struct.
Sourcepub fn with_spread_table(self, value: impl Into<Decimal>) -> Self
pub fn with_spread_table(self, value: impl Into<Decimal>) -> Self
Sets the spread_table field of this struct.
Sourcepub fn with_symbol(self, value: impl Into<String>) -> Self
pub fn with_symbol(self, value: impl Into<String>) -> Self
Sets the symbol field of this struct.
Sourcepub fn with_timestamp(self, value: impl Into<u64>) -> Self
pub fn with_timestamp(self, value: impl Into<u64>) -> Self
Sets the timestamp field of this struct.