pub struct StreamGetTickPricesSubscribe {
pub symbol: String,
pub min_arrival_time: Option<u64>,
pub max_level: Option<u64>,
}Fields
symbol: StringFinancial instrument symbol
min_arrival_time: Option<u64>Minimal interval in milliseconds between any two consecutive updates. It is optional.
max_level: Option<u64>Specifies the maximum level of the quote that the user is interested in. It is optional.
Implementations
Sourceimpl StreamGetTickPricesSubscribe
impl StreamGetTickPricesSubscribe
Sourcepub fn with_symbol(self, value: impl Into<String>) -> Self
pub fn with_symbol(self, value: impl Into<String>) -> Self
Sets the symbol field of this struct.
Sourcepub fn with_min_arrival_time(self, value: impl Into<u64>) -> Self
pub fn with_min_arrival_time(self, value: impl Into<u64>) -> Self
Sets the min_arrival_time field of this struct.
Sourcepub fn with_max_level(self, value: impl Into<u64>) -> Self
pub fn with_max_level(self, value: impl Into<u64>) -> Self
Sets the max_level field of this struct.