TradeRecord

Struct TradeRecord 

pub struct TradeRecord {
Show 26 fields pub close_price: Decimal, pub close_time: Option<u64>, pub close_time_string: Option<String>, pub closed: bool, pub cmd: TradingCommand, pub comment: String, pub commission: Option<Decimal>, pub custom_comment: String, pub digits: u32, pub expiration: Option<u64>, pub expiration_string: Option<String>, pub margin_rate: Decimal, pub offset: u32, pub open_price: Decimal, pub open_time: u64, pub open_time_string: String, pub order: u32, pub order2: u32, pub position: u32, pub profit: Decimal, pub sl: Decimal, pub storage: Decimal, pub symbol: Option<String>, pub timestamp: u64, pub tp: Decimal, pub volume: Decimal,
}
Structure representing a trade order

Fields

close_price: Decimal

Close price in base currency

close_time: Option<u64>

Null if order is not closed

close_time_string: Option<String>

Null if order is not closed

closed: bool

Closed

cmd: TradingCommand

Operation code

comment: String

Comment

commission: Option<Decimal>

Commission in account currency, null if not applicable

custom_comment: String

The value the customer may provide in order to retrieve it later.

digits: u32

Number of decimal places

expiration: Option<u64>

Null if order is not closed

expiration_string: Option<String>

Null if order is not closed

margin_rate: Decimal

Margin rate

offset: u32

Trailing offset

open_price: Decimal

Open price in base currency

open_time: u64

Open time

open_time_string: String

Open time string

order: u32

Order number for opened transaction

order2: u32

Order number for closed transaction

position: u32

Order number common both for opened and closed transaction

profit: Decimal

Profit in account currency

sl: Decimal

Zero if stop loss is not set (in base currency)

storage: Decimal

Order swaps in account currency

symbol: Option<String>

Symbol name or null for deposit/withdrawal operations

timestamp: u64

Timestamp

tp: Decimal

Zero if take profit is not set (in base currency)

volume: Decimal

Volume in lots

Implementations

Source

impl TradeRecord

pub fn with_close_price(self, value: impl Into<Decimal>) -> Self

Sets the close_price field of this struct.

pub fn with_close_time(self, value: impl Into<u64>) -> Self

Sets the close_time field of this struct.

pub fn with_close_time_string(self, value: impl Into<String>) -> Self

Sets the close_time_string field of this struct.

pub fn with_closed(self, value: impl Into<bool>) -> Self

Sets the closed field of this struct.

pub fn with_cmd(self, value: impl Into<TradingCommand>) -> Self

Sets the cmd field of this struct.

pub fn with_comment(self, value: impl Into<String>) -> Self

Sets the comment field of this struct.

pub fn with_commission(self, value: impl Into<Decimal>) -> Self

Sets the commission field of this struct.

pub fn with_custom_comment(self, value: impl Into<String>) -> Self

Sets the custom_comment field of this struct.

pub fn with_digits(self, value: impl Into<u32>) -> Self

Sets the digits field of this struct.

pub fn with_expiration(self, value: impl Into<u64>) -> Self

Sets the expiration field of this struct.

pub fn with_expiration_string(self, value: impl Into<String>) -> Self

Sets the expiration_string field of this struct.

pub fn with_margin_rate(self, value: impl Into<Decimal>) -> Self

Sets the margin_rate field of this struct.

pub fn with_offset(self, value: impl Into<u32>) -> Self

Sets the offset field of this struct.

pub fn with_open_price(self, value: impl Into<Decimal>) -> Self

Sets the open_price field of this struct.

pub fn with_open_time(self, value: impl Into<u64>) -> Self

Sets the open_time field of this struct.

pub fn with_open_time_string(self, value: impl Into<String>) -> Self

Sets the open_time_string field of this struct.

pub fn with_order(self, value: impl Into<u32>) -> Self

Sets the order field of this struct.

pub fn with_order2(self, value: impl Into<u32>) -> Self

Sets the order2 field of this struct.

pub fn with_position(self, value: impl Into<u32>) -> Self

Sets the position field of this struct.

pub fn with_profit(self, value: impl Into<Decimal>) -> Self

Sets the profit field of this struct.

pub fn with_sl(self, value: impl Into<Decimal>) -> Self

Sets the sl field of this struct.

pub fn with_storage(self, value: impl Into<Decimal>) -> Self

Sets the storage field of this struct.

pub fn with_symbol(self, value: impl Into<String>) -> Self

Sets the symbol field of this struct.

pub fn with_timestamp(self, value: impl Into<u64>) -> Self

Sets the timestamp field of this struct.

pub fn with_tp(self, value: impl Into<Decimal>) -> Self

Sets the tp field of this struct.

pub fn with_volume(self, value: impl Into<Decimal>) -> Self

Sets the volume field of this struct.