Structure representing details of a calendar record
Specification and constraints for the requested data
Structure representing chart range information
Response message returned from server when operation fails.
Only logic struct to keep symmetry.
The getAllSymbols command has no request data.
Wrapper for symbols
The request has no data. This struct exists only to keep symmetry
Get chart information
Please note that this function can be usually replaced by its streaming equivalent getCandles
which is the preferred way of retrieving current candle data.
Structure representing details of rate information
Structure representing chart range details
Request for calculation of commission
Structure representing account details
Structure representing IB’s history block
Structure representing account financial information
Structure representing margin information
Structure representing a specific Time span
Structure representing the order with operation code, price and volume
Structure representing profit information
Structure representing time information
Structure representing a symbol
Structure representing a level
Structure representing a time interval
Structure representing IB data
Structure representing user’s login data
Only logic struct to keep symmetry.
The login command has no response.
Structure representing a news item
Structure representing details of a rate
Message sent to XTB servers
Response message returned from server when operation succeeds.
Structure representing a record step
Structure representing a step rule
Data stream item representation
Subscribe for stream of data
Structure representing details of a financial symbol
Structure representing market price data
Structure representing a trade order
Structure embedding a TRADE_TRANS_INFO instance
Structure representing the response
Unsubscribe from stream of data