pub struct NewsBodyRecord {
pub body: String,
pub body_len: usize,
pub key: String,
pub time: u64,
pub time_string: String,
pub title: String,
}Expand description
Structure representing a news item
Fields
body: StringNews body content
body_len: usizeLength of the news body content
key: StringThe key of the news item
time: u64Time when the news was posted, represented as a UNIX timestamp
time_string: StringTime when the news was posted, presented in string format
title: StringTitle of the news item
Implementations
Sourceimpl NewsBodyRecord
impl NewsBodyRecord
Sourcepub fn with_body_len(self, value: impl Into<usize>) -> Self
pub fn with_body_len(self, value: impl Into<usize>) -> Self
Sets the body_len field of this struct.
Sourcepub fn with_time_string(self, value: impl Into<String>) -> Self
pub fn with_time_string(self, value: impl Into<String>) -> Self
Sets the time_string field of this struct.
Sourcepub fn with_title(self, value: impl Into<String>) -> Self
pub fn with_title(self, value: impl Into<String>) -> Self
Sets the title field of this struct.